@@ -17,7 +17,7 @@
 
 struct _GsAppReviewsDialog
 {
-	AdwWindow	 parent_instance;
+	AdwDialog	 parent_instance;
 	GtkWidget	*listbox;
 	GtkWidget	*stack;
 
@@ -28,7 +28,7 @@ struct _GsAppReviewsDialog
 	GsOdrsProvider	*odrs_provider;  /* (nullable) (owned), NULL if reviews are disabled */
 };
 
-G_DEFINE_TYPE (GsAppReviewsDialog, gs_app_reviews_dialog, ADW_TYPE_WINDOW)
+G_DEFINE_TYPE (GsAppReviewsDialog, gs_app_reviews_dialog, ADW_TYPE_DIALOG)
 
 typedef enum {
 	PROP_APP = 1,
@@ -85,8 +85,6 @@ review_button_clicked_cb (GsReviewRow        *row,
 						review, self->cancellable,
 						&local_error);
 		break;
-	case GS_REVIEW_ACTION_DISMISS:
-		/* The dismiss action is only used from the moderate page. */
 	default:
 		g_assert_not_reached ();
 	}
@@ -426,8 +424,6 @@ gs_app_reviews_dialog_class_init (GsAppReviewsDialogClass *klass)
 
 	gtk_widget_class_bind_template_child (widget_class, GsAppReviewsDialog, listbox);
 	gtk_widget_class_bind_template_child (widget_class, GsAppReviewsDialog, stack);
-
-	gtk_widget_class_add_binding_action (widget_class, GDK_KEY_Escape, 0, "window.close", NULL);
 }
 
 static void
@@ -456,21 +452,18 @@ gs_app_reviews_dialog_init (GsAppReviewsDialog *self)
  * Since: 42
  */
 GtkWidget *
-gs_app_reviews_dialog_new (GtkWindow *parent, GsApp *app, GsOdrsProvider *odrs_provider, GsPluginLoader *plugin_loader)
+gs_app_reviews_dialog_new (GsApp *app, GsOdrsProvider *odrs_provider, GsPluginLoader *plugin_loader)
 {
 	GsAppReviewsDialog *self;
 
-	g_return_val_if_fail (parent == NULL || GTK_IS_WINDOW (parent), NULL);
 	g_return_val_if_fail (app == NULL || GS_IS_APP (app), NULL);
 	g_return_val_if_fail (odrs_provider == NULL || GS_IS_ODRS_PROVIDER (odrs_provider), NULL);
 	g_return_val_if_fail (plugin_loader == NULL ||GS_IS_PLUGIN_LOADER (plugin_loader), NULL);
 
 	self = g_object_new (GS_TYPE_APP_REVIEWS_DIALOG,
 			     "app", app,
-			     "modal", TRUE,
 			     "odrs-provider", odrs_provider,
 			     "plugin-loader", plugin_loader,
-			     "transient-for", parent,
 			     NULL);
 
 	return GTK_WIDGET (self);
