@@ -26,6 +26,10 @@
 
 #define MAX_COLLAPSED_LINES 4
 
+/* How many lines should be hidden at least, to not "save"
+   less space than the button height. */
+#define MIN_HIDDEN_LINES 3
+
 struct _GsDescriptionBox {
 	GtkWidget parent;
 	GtkWidget *box;
@@ -53,9 +57,10 @@ static GParamSpec *obj_props[PROP_TEXT + 1] = { NULL, };
 static void
 gs_description_box_update_content (GsDescriptionBox *box)
 {
-	GtkAllocation allocation;
+	gint width, height;
 	PangoLayout *layout;
 	gint n_lines;
+	gboolean visible;
 	const gchar *text;
 
 	if (!box->text || !*(box->text)) {
@@ -64,17 +69,18 @@ gs_description_box_update_content (GsDescriptionBox *box)
 		return;
 	}
 
-	gtk_widget_get_allocation (GTK_WIDGET (box), &allocation);
+	width = gtk_widget_get_width (GTK_WIDGET (box));
+	height = gtk_widget_get_height (GTK_WIDGET (box));
 
-	if (!box->needs_recalc && box->last_width == allocation.width && box->last_height == allocation.height)
+	if (!box->needs_recalc && box->last_width == width && box->last_height == height)
 		return;
 
 	if ((!gtk_widget_get_visible (GTK_WIDGET (box->button))) == (!box->always_expanded))
 		gtk_widget_set_visible (GTK_WIDGET (box->button), !box->always_expanded);
 
-	box->needs_recalc = allocation.width <= 1 || allocation.height <= 1;
-	box->last_width = allocation.width;
-	box->last_height = allocation.height;
+	box->needs_recalc = width <= 1 || height <= 1;
+	box->last_width = width;
+	box->last_height = height;
 
 	if (box->always_expanded) {
 		gtk_widget_set_visible (GTK_WIDGET (box->button), FALSE);
@@ -96,10 +102,11 @@ gs_description_box_update_content (GsDescriptionBox *box)
 
 	layout = gtk_label_get_layout (box->label);
 	n_lines = pango_layout_get_line_count (layout);
+	visible = n_lines > MAX_COLLAPSED_LINES && n_lines - MAX_COLLAPSED_LINES >= MIN_HIDDEN_LINES;
 
-	gtk_widget_set_visible (GTK_WIDGET (box->button), n_lines > MAX_COLLAPSED_LINES);
+	gtk_widget_set_visible (GTK_WIDGET (box->button), visible);
 
-	if (box->is_collapsed && n_lines > MAX_COLLAPSED_LINES) {
+	if (box->is_collapsed && visible) {
 		PangoLayoutLine *line;
 		GString *str;
 		GSList *opened_markup = NULL;
